from flask import Flask
from flask_cors import CORS
from flask_jwt_extended import JWTManager
from flask_oauthlib.client import OAuth

from portal.config import CONFIGURATIONS
from portal.tools.paths import ROOT_DIR
from flask_sqlalchemy import SQLAlchemy

import os
from storage import Storage

db = SQLAlchemy()
jwt = JWTManager()
oauth = OAuth()
cors = CORS(resources=r'*', origins=[r'http://localhost:4200/*', 'https://*.pstanko.net/*'], supports_credentials=True)
# TODO - urgent
storage = Storage({
    "submissions_dir": "todo",
    "test_files_dir": "todo",
    "workspace_dir": "todo"
})


def config_app(flask_app):
    """Configures the Flask app based on production stage."""
    config_type = os.environ.get('PORTAL_CONFIG_TYPE', 'devel')
    config_object = CONFIGURATIONS[config_type]
    if config_object is None:
        raise RuntimeError()
    flask_app.config.from_object(config_object)
    flask_app.config.from_pyfile(ROOT_DIR + '/portal.local.cfg', silent=True)
    flask_app.config.from_envvar('PORTAL_CONFIG', silent=True)
    # app.logger.removeHandler(default_handler) # from Flask release 1.0, not yet available


def create_app():
    app = Flask('portal')
    # app configuration
    config_app(app)
    # database bind to app
    db.init_app(app)
    # init the jwt
    jwt.init_app(app)
    # init the oauth client
    oauth.init_app(app)
    # init CORS
    cors.init_app(app)
    return app


import portal.database.models
